MoveToBoundary

Struct MoveToBoundary 

pub struct MoveToBoundary<T> { /* private fields */ }
The struct to limit the coordinates of particle.

Implementations

Source

impl<T> MoveToBoundary<T>

pub fn new(intervals: Vec<(T, T)>) -> Self

Constructor.

Parameters

intervals - intervals - vector of tuples. Size of the vector must be equal to dimension. The first value in tuple is minimum coordinate, the second value is maximum coordinate.